@@ -6,7 +6,6 @@ import (
 	"net"
 	"os"
 	"path/filepath"
-	"reflect"
 	"strconv"
 	"strings"
 	"sync"
@@ -19,25 +18,28 @@ import (
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/informer"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/kube"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/util"
+
 	kapi "k8s.io/api/core/v1"
+	apiequality "k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/tools/record"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 )
 
 // OvnNode is the object holder for utilities meant for node management
 type OvnNode struct {
 	name         string
 	Kube         kube.Interface
-	watchFactory *factory.WatchFactory
+	watchFactory factory.NodeWatchFactory
 	stopChan     chan struct{}
 	recorder     record.EventRecorder
+	gateway      Gateway
 }
 
 // NewNode creates a new controller for node management
-func NewNode(kubeClient kubernetes.Interface, wf *factory.WatchFactory, name string, stopChan chan struct{}, eventRecorder record.EventRecorder) *OvnNode {
+func NewNode(kubeClient kubernetes.Interface, wf factory.NodeWatchFactory, name string, stopChan chan struct{}, eventRecorder record.EventRecorder) *OvnNode {
 	return &OvnNode{
 		name:         name,
 		Kube:         &kube.Kube{KClient: kubeClient},
@@ -208,13 +210,14 @@ func (n *OvnNode) Start(wg *sync.WaitGroup) error {
 	nodeAnnotator := kube.NewNodeAnnotator(n.Kube, node)
 	waiter := newStartupWaiter()
 
-	// Initialize gateway resources on the node
-	if err := n.initGateway(subnets, nodeAnnotator, waiter); err != nil {
+	// Initialize management port resources on the node
+	mgmtPortConfig, err := createManagementPort(n.name, subnets, nodeAnnotator, waiter)
+	if err != nil {
 		return err
 	}
 
-	// Initialize management port resources on the node
-	if err := n.createManagementPort(subnets, nodeAnnotator, waiter); err != nil {
+	// Initialize gateway resources on the node
+	if err := n.initGateway(subnets, nodeAnnotator, waiter, mgmtPortConfig); err != nil {
 		return err
 	}
 
@@ -228,15 +231,15 @@ func (n *OvnNode) Start(wg *sync.WaitGroup) error {
 	if err := waiter.Wait(); err != nil {
 		return err
 	}
+	go n.gateway.Run(n.stopChan, wg)
 	klog.Infof("Gateway and management port readiness took %v", time.Since(start))
 
 	if config.HybridOverlay.Enabled {
-		factory := n.watchFactory.GetFactory()
 		nodeController, err := honode.NewNode(
 			n.Kube,
 			n.name,
-			factory.Core().V1().Nodes().Informer(),
-			factory.Core().V1().Pods().Informer(),
+			n.watchFactory.NodeInformer(),
+			n.watchFactory.LocalPodInformer(),
 			informer.NewDefaultEventHandler,
 		)
 		if err != nil {
@@ -256,6 +259,9 @@ func (n *OvnNode) Start(wg *sync.WaitGroup) error {
 	// start health check to ensure there are no stale OVS internal ports
 	go checkForStaleOVSInterfaces(n.stopChan)
 
+	// start management port health check
+	go checkManagementPortHealth(mgmtPortConfig, n.stopChan)
+
 	confFile := filepath.Join(config.CNI.ConfDir, config.CNIConfFileName)
 	_, err = os.Stat(confFile)
 	if os.IsNotExist(err) {
@@ -265,14 +271,9 @@ func (n *OvnNode) Start(wg *sync.WaitGroup) error {
 		}
 	}
 
-	kclient, ok := n.Kube.(*kube.Kube)
-	if !ok {
-		return fmt.Errorf("cannot get kubeclient for starting CNI server")
-	}
 	n.WatchEndpoints()
 
-	// start the cni server
-	cniServer := cni.NewCNIServer("", kclient.KClient)
+	cniServer := cni.NewCNIServer("", n.watchFactory)
 	err = cniServer.Start(cni.HandleCNIRequest)
 
 	return err
@@ -283,7 +284,7 @@ func (n *OvnNode) WatchEndpoints() {
 		UpdateFunc: func(old, new interface{}) {
 			epNew := new.(*kapi.Endpoints)
 			epOld := old.(*kapi.Endpoints)
-			if reflect.DeepEqual(epNew.Subsets, epOld.Subsets) {
+			if apiequality.Semantic.DeepEqual(epNew.Subsets, epOld.Subsets) {
 				return
 			}
 			newEpAddressMap := buildEndpointAddressMap(epNew.Subsets)
