@@ -6,6 +6,7 @@ import (
 	"strings"
 	"time"
 
+	hotypes "github.com/ovn-org/ovn-kubernetes/go-controller/hybrid-overlay/pkg/types"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/config"
 	addressset "github.com/ovn-org/ovn-kubernetes/go-controller/pkg/ovn/address_set"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/util"
@@ -190,6 +191,24 @@ func (oc *Controller) AddNamespace(ns *kapi.Namespace) {
 	defer nsInfo.Unlock()
 
 	var err error
+	annotation := ns.Annotations[hotypes.HybridOverlayExternalGw]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay external gw annotation")
+		} else {
+			nsInfo.hybridOverlayExternalGW = parsedAnnotation
+		}
+	}
+	annotation = ns.Annotations[hotypes.HybridOverlayVTEP]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay VTEP annotation")
+		} else {
+			nsInfo.hybridOverlayVTEP = parsedAnnotation
+		}
+	}
 	if annotation, ok := ns.Annotations[routingExternalGWsAnnotation]; ok {
 		nsInfo.routingExternalGWs.gws, err = parseRoutingExternalGWAnnotation(annotation)
 		if err != nil {
@@ -276,6 +295,28 @@ func (oc *Controller) updateNamespace(old, newer *kapi.Namespace) {
 			}
 		}
 	}
+	annotation := newer.Annotations[hotypes.HybridOverlayExternalGw]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay external gw annotation")
+		} else {
+			nsInfo.hybridOverlayExternalGW = parsedAnnotation
+		}
+	} else {
+		nsInfo.hybridOverlayExternalGW = nil
+	}
+	annotation = newer.Annotations[hotypes.HybridOverlayVTEP]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay VTEP annotation")
+		} else {
+			nsInfo.hybridOverlayVTEP = parsedAnnotation
+		}
+	} else {
+		nsInfo.hybridOverlayVTEP = nil
+	}
 	oc.multicastUpdateNamespace(newer, nsInfo)
 }
 
